@@ -644,6 +644,28 @@ namespace NpgsqlTests
             
             Assert.AreEqual(1, i);
         }
+
+        [Test]
+        public void SingleRowForwardOnlyCommandBehaviorSupport()
+        {
+            NpgsqlCommand command = new NpgsqlCommand("select * from tablea", TheConnection);
+            Int32 i = 0;
+
+            using (NpgsqlDataReader dr = command.ExecuteReader(CommandBehavior.SingleRow | CommandBehavior.SequentialAccess))
+            {
+
+                while (dr.Read())
+                {
+                    if (!dr.IsDBNull(0))
+                        dr.GetValue(0);
+                    if (!dr.IsDBNull(1))
+                        dr.GetValue(1);
+                    i++;
+                }
+            }
+
+            Assert.AreEqual(1, i);
+        }
         
         
         [Test]
@@ -992,26 +1014,82 @@ namespace NpgsqlTests
             
         }
         
+        
+
         [Test]
-        public void GetValueWithNullFields()
+
+        public void TestOutParameter2()
+
         {
-            NpgsqlCommand command = new NpgsqlCommand("select * from tableb", TheConnection);
+
+            NpgsqlCommand command = new NpgsqlCommand("testoutparameter2", TheConnection);
+
+            command.CommandType = CommandType.StoredProcedure;
+            
+            command.Parameters.Add(new NpgsqlParameter("@x", NpgsqlDbType.Integer)).Value = 1;
+            command.Parameters.Add(new NpgsqlParameter("@y", NpgsqlDbType.Integer)).Value = 2;
+            command.Parameters.Add(new NpgsqlParameter("@sum", NpgsqlDbType.Integer));
+            command.Parameters.Add(new NpgsqlParameter("@product", NpgsqlDbType.Refcursor));
+            
+            command.Parameters["@sum"].Direction = ParameterDirection.Output;
+            command.Parameters["@product"].Direction = ParameterDirection.Output;
+            
             using (NpgsqlDataReader dr = command.ExecuteReader())
             {
                 dr.Read();
                 
-                Boolean result = dr.IsDBNull(2);
-
-                Assert.IsTrue(result);
+                Assert.AreEqual(3, command.Parameters["@sum"].Value);
+                Assert.AreEqual(2, command.Parameters["@product"].Value);
                 
                 
            
             }
             
-            
-            
-            
         }
+
+
+
+        [Test]
+
+        public void GetValueWithNullFields()
+
+        {
+
+            NpgsqlCommand command = new NpgsqlCommand("select * from tableb", TheConnection);
+
+            using (NpgsqlDataReader dr = command.ExecuteReader())
+
+            {
+
+                dr.Read();
+
+
+
+                Boolean result = dr.IsDBNull(2);
+
+
+
+                Assert.IsTrue(result);
+
+
+
+
+
+
+
+            }
+
+
+
+
+
+
+
+
+
+        }
+
+
         
         [Test]
         public void HasRowsGetValue()
